Maintainers
===========

- Brian Armstrong (`barm <https://github.com/barm>`_)
- David Grochowski (`ThePumpingLemma <https://github.com/ThePumpingLemma>`_)
- Kyle Seever (`kseever <https://github.com/kseever>`_)
- Micah Denbraver (`macro1 <https://github.com/macro1>`_)
- Ross Mechanic (`rossmechanic <https://github.com/rossmechanic>`_)
- Trey Hunner (`treyhunner <https://github.com/treyhunner>`_)

Authors
=======

- Adnan Umer (`uadnan <https://github.com/uadnan>`_)
- Aleksey Kladov
- Alexander Anikeev
- Ben Lawson (`blawson <https://github.com/blawson>`_)
- `bradford281 <https://github.com/bradford281>`_
- Brian Armstrong (`barm <https://github.com/barm>`_)
- Buddy Lindsey, Jr.
- Brian Dixon
- Christopher Broderick (`uhurusurfa <https://github.com/uhurusurfa>`_)
- Corey Bertram
- Damien Nozay
- Daniel Gilge
- Daniel Levy
- Daniel Roschka
- David Grochowski (`ThePumpingLemma <https://github.com/ThePumpingLemma>`_)
- David Hite
- Eduardo Cuducos
- Florian Eßer
- Frank Sachsenheim
- George Vilches
- Gregory Bataille
- Grzegorz Bialy
- Hamish Downer
- Hanyin Zhang
- James Muranga (`jamesmura <https://github.com/jamesmura>`_)
- James Pulec
- Jesse Shapiro
- Jim Gomez
- Joao Junior (`joaojunior <https://github.com/joaojunior>`_)
- Joao Pedro Francese
- `jofusa <https://github.com/jofusa>`_
- John Whitlock
- Jonathan Leroy
- Jonathan Sanchez
- Jonathan Zvesper (`zvesp <https://github.com/zvesp>`_)
- Josh Fyne
- Kevin Foster
- Klaas van Schelven
- Kris Neuharth
- Kyle Seever (`kseever <https://github.com/kseever>`_)
- Leticia Portella
- Lucas Wiman
- Maciej "RooTer" Urbański
- Mark Davidoff
- Martin Bachwerk
- Marty Alchin
- Matheus Cansian (`mscansian <https://github.com/mscansian>`_)
- Mauricio de Abreu Antunes
- Micah Denbraver
- Michael England
- Miguel Vargas
- Mike Spainhower
- Nathan Villagaray-Carski (`ncvc <https://github.com/ncvc>`_)
- Nianpeng Li
- Phillip Marshall
- Rajesh Pappula
- Ray Logel
- Roberto Aguilar
- Rod Xavier Bondoc
- Ross Lote
- Ross Mechanic (`rossmechanic <https://github.com/rossmechanic>`_)
- Ross Rogers
- Sergey Ozeranskiy (`ozeranskiy <https://github.com/ozeranskiy>`_)
- Shane Engelman
- Steeve Chailloux
- Steven Klass
- Tommy Beadle (`tbeadle <https://github.com/tbeadle>`_)
- Trey Hunner (`treyhunner <https://github.com/treyhunner>`_)
- Ulysses Vilela
- `vnagendra <https://github.com/vnagendra>`_

Background
==========

This code originally comes from Pro Django, published by Apress, Inc.
in December 2008. The author of the book and primary author
of the code is Marty Alchin <marty@martyalchin.com>, who
may be found online at <http://martyalchin.com/>.

As part of the technical review process, additional code
modifications were provided by the technical reviewer,
George Vilches <gav@thataddress.com>.

This code was originally extended, licensed, and improved by
Corey Bertram <corey@qr7.com> with the permission of Marty Alchin.
